@@ -8,9 +8,9 @@ class Dataset(object):
 
     def __init__(self, id, train_end, val_end, test_end):
         self.id = id
-        self.train_end = train_end
-        self.val_end = val_end
-        self.test_end = test_end
+        self.__train_end = train_end
+        self.__val_end = val_end
+        self.__test_end = test_end
 
     def __str__(self):
         return self.id
@@ -24,7 +24,7 @@ class Dataset(object):
         Property for training subset
         :return: slice
         """
-        return self[0:self.train_end]
+        return self[0:self.__train_end]
 
     @property
     def val(self):
@@ -32,7 +32,7 @@ class Dataset(object):
         Property for validation subset
         :return: slice
         """
-        return self[self.train_end:self.val_end]
+        return self[self.__train_end:self.__val_end]
 
     @property
     def test(self):
@@ -40,4 +40,4 @@ class Dataset(object):
         Property for test subset
         :return: slice
         """
-        return self[self.val_end:self.train_end]
+        return self[self.__val_end:self.__train_end]
