@@ -7,8 +7,16 @@ from progress.spinner import Spinner
 
 from .web.urls import TASK_STATUS_URL
 
+FAILURE = "FAILURE"
+PENDING = "PENDING"
+COMPLETE = "COMPLETE"
+STOPPED = "STOPPED"
+
+TASK_DONE_LIST = (FAILURE, COMPLETE, STOPPED)
+
 import threading
 
+
 class Task:
 
     def __init__(self, task_id, callback=None, show=True):
@@ -16,7 +24,7 @@ class Task:
         self.task_result = ""
         self.task_type = ""
         self.progress = 0
-        self.task_state = "PENDING"
+        self.task_state = PENDING
         self.callback = callback
         if self.callback:
             t = threading.Thread(target=self.callback_thread)
@@ -36,9 +44,11 @@ class Task:
                 bar.goto(self.progress*100)
             else:
                 spinner.next()
-        if self.task_state == "FAILURE":
+        if self.task_state == FAILURE:
             self.update(include_result=True)
             raise Exception("ERROR:" + str(self.task_result))
+        if self.task_state == STOPPED:
+            print("Task has been stopped.")
         if show_progress:
             bar.finish()
         else:
@@ -68,6 +78,6 @@ class Task:
 
     def finished(self):
         self.update()
-        return self.task_state in ("COMPLETE", "FAILURE")
+        return self.task_state in TASK_DONE_LIST
 
 
