@@ -45,16 +45,20 @@ def sliceData(data):
 
 
 def uploadData(data):
+    print("Saving data locally...")
     if isinstance(data, str):
         file = open(data, "rb")
     else:
         file = save_data(data)
+    print("Hashing...")
     hash = hashlib.md5(file.read()).hexdigest()
+    print("Checking if data is on servers...")
     params = {"token": getToken(), "hash": hash, "collection": 1}
     response = requests.get(HASH_URL, params=params)
     if response.status_code == 200:
         file.close()
         return response
+    print("Data not found on servers. Uploading now...")
     file.seek(0)
     files = {'file': file}
     response = requests.post(UPLOAD_DATA_URL, files=files, params=params)
@@ -62,6 +66,8 @@ def uploadData(data):
         file.close()
     return response
 
+def hashData(data):
+    pass
 
 
 
