@@ -4,7 +4,7 @@
 """
 
 
-def SGD(lr=0.001, momentum=0.9):
+def SGD(lr=0.001, momentum=0):
     """SGD Optimiser.
 
           :param lr: Learning rate
@@ -20,7 +20,7 @@ def SGD(lr=0.001, momentum=0.9):
         }}
 
 
-def RMS(lr=0.001, decay=1e-6):
+def RMS(lr=0.001, decay=0):
     """RMS Optimiser.
 
               :param lr: Learning rate
@@ -36,7 +36,7 @@ def RMS(lr=0.001, decay=1e-6):
         }}
 
 
-def Adam(lr=0.001, beta1=0.9, beta2=0.999, epsilon=1e-08):
+def Adam(lr=0.001):#, beta1=0.9, beta2=0.999, epsilon=1e-08):
     """Adam Optimiser.
 
               :param lr: Learning rate
@@ -49,10 +49,10 @@ def Adam(lr=0.001, beta1=0.9, beta2=0.999, epsilon=1e-08):
               :type epsilon: float
           """
     return {
-        "optimiser": "RMS",
+        "optimiser": "Adam",
         "opt_args": {
-            "lr": lr,
-            "beta1": beta1,
-            "beta2": beta2,
-            "epsilon": epsilon,
-        }}
\ No newline at end of file
+            "lr": lr
+#             "beta1": beta1,
+#             "beta2": beta2,
+#             "epsilon": epsilon,
+        }}
